@@ -66,6 +66,7 @@ class EventBroadcaster:
         self._notifier = notifier
         self._is_publish_only = is_publish_only
         self._lock = asyncio.Lock()
+        self._publish_lock = asyncio.Lock()
         self._num_connections = 0
 
     async def __broadcast_notifications__(self, subscription: Subscription, data):
@@ -81,8 +82,9 @@ class EventBroadcaster:
         note = BroadcastNotification(notifier_id=self._id, topics=[
                                      subscription.topic], data=data)
         # Publish event to broadcast
-        async with self._broadcast:
-            await self._broadcast.publish(self._channel, note.json())
+        async with self._publish_lock:
+            async with self._broadcast:
+                await self._broadcast.publish(self._channel, note.json())
 
     async def __aenter__(self):
         async with self._lock:
@@ -127,7 +129,7 @@ class EventBroadcaster:
         # Make sure a task wasn't started already
         if self._subscription_task is not None:
             # we already started a task for this worker process
-            logger.info("No need for listen task, already started broadcast listen task for this notifier")
+            logger.debug("No need for listen task, already started broadcast listen task for this notifier")
             return
         # Trigger the task
         logger.info("Spawning broadcast listen task")
@@ -151,7 +153,7 @@ class EventBroadcaster:
                             event.message)
                         # Avoid re-publishing our own broadcasts
                         if notification.notifier_id != self._id:
-                            logger.info("Handling incoming broadcast event",
+                            logger.debug("Handling incoming broadcast event",
                                         {'topics':notification.topics,
                                         'src':notification.notifier_id})
                             # Notify subscribers of message received from broadcast
